/**
 * Data structure for stock information.
 * Conforms to the schema in the StockData.xsd file.
 * Class is dynamic so new properties can be added to 
 * StockItem instances if needed.
 */
dynamic class StockItem {
	
	/**
	 * The abbreviated symbol for the stock on its exchange.
	 * May be up to 4 characters in length.
	 */
	public var symbol:String = "";	
	public var company:String = "";
	public var lastPrice:String  = "";
	public var tradedDate:String  = "";
	public var tradedTime:String  = "";
	public var change:String  = "";
	public var changePercent:String  = "";
	public var earnPerShare:String  = "";
	public var PE:String  = "";
	public var marketCap:String= "";
	public var divShare:String  = "";
	public var open:String  = "";
	public var yesterdayClose:String  = "";
	public var bid:String = "";
	public var ask:String = "";
	public var dayLow:String  = "";
	public var dayHigh:String  = "";
	public var dayHighString:String  = "";
	public var yearLow:String  = "";
	public var yearHigh:String  = "";
	public var volume:String  = "";
	public var averageVolume:String = "";
	public var divDate:String = "";
	public var yield:String = "";
	public var date:String = "";
	
	/**
	 * Internal ID number for this stock in the list.
	 */
	private var __ID__:Number;

	/**
	 * Standard constructor just takes symbol and company name.
	 * Other data will be filled in using the web service query method.
	 */
	public function StockItem(symbol:String, companyName:String)
	{
		this.symbol = symbol;
		if (companyName != undefined) {
			this.company = companyName;
		}
	}
	
	/**
	 * Creates a StockItem instance from an anonymous object with similar properties.
	 */
	public static function create(item:Object):StockItem {
		var stock:StockItem = new StockItem();

		stock.symbol = item.symbol;	
		stock.company= item.company;
		stock.lastPrice = item.lastPrice;
		stock.tradedDate = item.tradedDate;
		stock.tradedTime = item.tradedTime;
		stock.change = item.change;
		stock.changePercent = item.changePercent;
		stock.earnPerShare = item.earnPerShare;
		stock.PE = item.PE;
		stock.marketCap = item.marketCap;
		stock.divShare = item.divShare
		stock.open = item.open;
		stock.yesterdayClose = item.yesterdayClose;
		stock.bid = item.bid;
		stock.ask = item.ask;
		stock.dayLow = item.dayLow;
		stock.dayHigh  = item.dayHigh;
		stock.dayHighString  = item.dayHighString;
		stock.yearLow = item.yearLow;
		stock.yearHigh = item.yearHigh;
		stock.volume = item.volume;
		stock.averageVolume = item.averageVolume;
		stock.divDate = item.divDate;
		stock.yield = item.yield;
		stock.date = item.date;
		
		return stock;
	}
	
	/** 
	 * Convenience methods for display.
	 * Note that these methods won't work on a StockItem instance that has been 
	 * passed across an LCService connection, since Functions don't come across.
	 */
	public function getBidAsk():String 
	{
		StockUtils.trace("getBidAsk = " + this.bid + " - " + this.ask, "StockItem");
		return this.bid + " - " + this.ask;
	}
		
	public function get changeAndPercent():String 
	{
		StockUtils.trace("get changeAndPercent = " + this.change + " (" + this.changePercent + ")", "StockItem");
		return this.change + " (" + this.changePercent + ")";
	}
	
	public function get dayRange():String 
	{
		return this.dayLow + " - " + this.dayHighString;
	}
	
	public function get yearRange():String 
	{
		return this.yearLow + " - " + this.yearHigh;
	}
	
}